@@ -8,13 +8,13 @@
 ### AUTHOR: Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 dzmgeom <- function (x, prob, p0, log = FALSE)
-    .External("actuar_do_dpq", "dzmgeom", x, prob, p0, log)
+    .External(C_actuar_do_dpq, "dzmgeom", x, prob, p0, log)
 
 pzmgeom <- function(q, prob, p0, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "pzmgeom", q, prob, p0, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "pzmgeom", q, prob, p0, lower.tail, log.p)
 
 qzmgeom <- function(p, prob, p0, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "qzmgeom", p, prob, p0, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "qzmgeom", p, prob, p0, lower.tail, log.p)
 
 rzmgeom <- function(n, prob, p0)
-    .External("actuar_do_random", "rzmgeom", n, prob, p0)
+    .External(C_actuar_do_random, "rzmgeom", n, prob, p0)
