@@ -9,16 +9,16 @@
 ### AUTHOR: Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 dztbinom <- function (x, size, prob, log = FALSE)
-    .External("actuar_do_dpq", "dztbinom", x, size, prob, log)
+    .External(C_actuar_do_dpq, "dztbinom", x, size, prob, log)
 
 pztbinom <- function(q, size, prob, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "pztbinom", q, size, prob, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "pztbinom", q, size, prob, lower.tail, log.p)
 
 qztbinom <- function(p, size, prob, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "qztbinom", p, size, prob, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "qztbinom", p, size, prob, lower.tail, log.p)
 
 rztbinom <- function(n, size, prob)
-    .External("actuar_do_random", "rztbinom", n, size, prob)
+    .External(C_actuar_do_random, "rztbinom", n, size, prob)
 
 ## not exported; for internal use in panjer()
 pgfztbinom <- function(x, size, prob)
