@@ -15,7 +15,7 @@
 
 /* DENSITY, CUMULATIVE PROBABILITY AND QUANTILE FUNCTIONS,
  * RAW AND LIMITED MOMENTS */
-DPQTAB dpq_tab[] = {
+dpq_tab_struct dpq_tab[] = {
     /* One parameter distributions */
     {"mexp",            actuar_do_dpq1,        1},
     {"dinvexp",         actuar_do_dpq1,        2},
@@ -180,14 +180,12 @@ DPQTAB dpq_tab[] = {
     {"mphtype",         actuar_do_dpqphtype2,  3},
     {"mgfphtype",       actuar_do_dpqphtype2,  4},
     /* Special integrals */
-    {"expint",          actuar_do_dpq0,        201},
-    {"gammaint",        actuar_do_dpq1,        201},
     {"betaint",         actuar_do_dpq2,        201},
     {0, 0, 0}
 };
 
 /* RANDOM NUMBERS FUNCTIONS */
-RANDOMTAB random_tab[] = {
+random_tab_struct random_tab[] = {
     /* One parameter distributions */
     {"rinvexp",         actuar_do_random1,     1, REALSXP},
     {"rlogarithmic",    actuar_do_random1,   101, INTSXP},
